# level.py
import upygame as upg
import tile
import tileCoin
import tilesData as td
import moveData as md
import levelData as ld
import gc

margin = 16

class Level():
    def __init__(self,tile_w,tile_h):
        self.levelIndex = 0
        self.w = 0
        self.h = 0
        self.tile_w = tile_w
        self.tile_h = tile_h
        self.columns = 0
        self.rows = 0
        self.tiles = []
        
    
    def loadLevel(self,levelIndex):
        self.levelIndex = levelIndex
        lvl = None
        self.tiles = None
        gc.collect()
        lvl = ld.levels[self.levelIndex]
        self.tiles = []
        
        self.columns = len(lvl[0])
        self.rows = len(lvl)
        self.w = self.columns * self.tile_w
        self.h = self.rows * self.tile_h
        print(str(self.columns) + 'x' + str(self.rows))
       
        xStart = 0
        yStart = 0 
        for x in range(0,self.columns):
            for y in range(0,self.rows):
                cell = lvl[y][x]
                xp = x * self.tile_w
                yp = y * self.tile_h
                newTile = None
                if cell == 'x':
                    newTile = tile.Tile(True,[td.boxPixels],xp,yp,12,12)
                if cell == 'w':
                    newTile = tile.Tile(True,[td.winPixels],xp,yp,12,12)
                if cell == 'o':
                    animPixels = [td.r1Pixels,td.r2Pixels,td.r3Pixels,td.r4Pixels,td.r5Pixels,td.r6Pixels]
                    #newTile = tile.Tile(False,animPixels,xp,yp,8,8)
                    newTile = tileCoin.TileCoin(False,animPixels,xp,yp,8,8)
                if cell == '|':
                    newTile = tile.Tile(True,[td.boxMovablePixels],xp,yp,12,12,md.MoveData(xp,yp,0,1,0,8))
                if cell == '-':
                    newTile = tile.Tile(True,[td.boxMovablePixels],xp,yp,12,12,md.MoveData(xp,yp,1,0,16,0))
                if cell == 'z':
                    newTile = tile.Tile(False,[td.exitPixels],xp,yp,12,12)
                if cell == 'a':
                    xStart = xp
                    yStart = yp
                
                if newTile:
                    self.tiles.append(newTile)

        #return Start point
        return xStart,yStart
    
    
    def loadNext(self,inc):
        self.levelIndex +=inc
        if(self.levelIndex>=len(ld.levels)):
            self.levelIndex = 0
        return self.loadLevel(self.levelIndex)
        
    
    def outOfMargin(self,player):
        if (player.xs > (self.w + margin) or player.xs < -margin or
        player.ys > (self.h + margin) or player.ys < -margin):
            return True
        else:
            return False
            
    
    def collideWith(self,rect):
        for t in self.tiles:
            if(t.collide(rect)):
                return t
                    
    def updateAndDraw(self,screen,cam):
        #boundres
        xb = cam.getX() - margin
        yb = cam.getY() - margin
        wb = self.w + 2*margin
        hb = self.h + 2*margin
        screen.fill(8,upg.Rect(xb,yb,wb,2))#top
        screen.fill(8,upg.Rect(xb,yb,2,hb))#left
        screen.fill(8,upg.Rect(xb+wb,yb,2,hb))#right
        screen.fill(8,upg.Rect(xb,yb+hb,wb,2))#bottom
        
        #tiles
        for t in self.tiles:
            t.update()
            t.draw(screen,cam)
           
            

        